/*
<:copyright-BRCM:2016:DUAL/GPL:standard

   Broadcom Proprietary and Confidential.(c) 2016 Broadcom
   All Rights Reserved

Unless you and Broadcom execute a separate written software license
agreement governing use of this software, this software is licensed
to you under the terms of the GNU General Public License version 2
(the "GPL"), available at http://www.broadcom.com/licenses/GPLv2.php,
with the following added to such license:

   As a special exception, the copyright holders of this software give
   you permission to link this software with independent modules, and
   to copy and distribute the resulting executable under terms of your
   choice, provided that you also meet, for each linked independent
   module, the terms and conditions of the license of that module.
   An independent module is a module which is not derived from this
   software.  The special exception does not apply to any modifications
   of the software.

Not withstanding the above, under no circumstances may you combine
this software in any way with any other Broadcom software provided
under a license other than the GPL, without Broadcom's express prior
written consent.

:>
 */
#ifndef MAPLE_CLI_HELPERS_H_
#define MAPLE_CLI_HELPERS_H_

#include <bcmcli.h>
#include <bcm_api_cli_types.h>

#ifdef __cplusplus
extern "C"
{
#endif

/* Mac name length */
#define APICLI_MAX_PARM_NAME_LENGTH BCMCLI_MAX_SEARCH_SUBSTR_LENGTH

/* Max help string length */
#define APICLI_MAX_PARM_HELP_LENGTH 128

typedef enum bcmcli_field_descr_flags
{
    BCMCLI_FIELD_DESCR_FLAGS_NONE           = 0,
    BCMCLI_FIELD_DESCR_FLAGS_PRESENCE_MASK  = (1 << 0)  /* field is a 'presence mask' for a structure */
} bcmcli_field_descr_flags;

typedef struct bcmcli_type_descr bcmcli_type_descr;

/* Structure field descriptor */
typedef struct bcmcli_field_descr
{
    const char *name;           /* Field name */
    const char *descr;          /* Field description */
    const char *cli_name;       /* Short CLI name. can be missing */
    bcmcli_type_descr *type;    /* Field type */
    uint16_t offset;            /* Offset from the beginning of the type structure */
    bcmcli_field_descr_flags flags;
} bcmcli_field_descr;

/* Data type descriptor */
struct bcmcli_type_descr
{
    const char *name;                           /* Type name */
    const char *descr;                          /* Type description. can be missing */
    const char *cli_name;                       /* Short CLI name. can be missing */
    bcmolt_base_type_id base_type;              /* Base type: snum, unum, string, ip, enum, etc. */
    uint32_t min_val;                           /* Min value for range check */
    uint32_t max_val;                           /* Max value for range check */
    uint16_t size;                              /* Size */

    /* The following union is qualified by the base_type and contains additional
     * info for array, enum, struct, union */
    union
    {
        bcmcli_enum_val *e;                     /* enum value array Contains num_elements+1 values. The last value has name=NULL */
        struct
        {
            uint16_t num_fields;                /* number of elements in the following structure */
            bcmcli_field_descr *fields;         /* Structure field array. Contains num_elements values */
        } s;
        struct
        {
            uint16_t num_common_fields;         /* number of non-union fields at the start of the struct */
            bcmcli_field_descr *common_fields;  /* common field array. Contains num_elements values */
            uint16_t classifier_idx;            /* index of the classifier field within common_fields */
            bcmcli_field_descr *union_fields;   /* sub-struct fields under the union (name == NULL if no fields present)
                                                   (one per enum entry in the classifier type, plus one for default) */
        } u;
        struct
        {
            bcmcli_type_descr *elem_type;       /* Array element type */
            uint8_t len_size;                   /* Byte width of array length field (at start of struct) */
            uint16_t max_size;                  /* Max array size */
        } arr_dyn;
        struct
        {
            bcmcli_type_descr *elem_type;       /* Array element type */
            uint16_t size;                      /* Fixed array size */
        } arr_fixed;
    } x;
};

/* Property descriptor.
 * The 1st 5 fields are exactly the same as in bcmcli_field_descr
 * ToDo: replace with bcmcli_field_descr substructure.
 * Requires changes in code generator
 */
typedef struct
{
    const char *name;               /* C name */
    const char *descr;              /* Property description */
    const char *cli_name;           /* CLI name */
    bcmcli_type_descr *type;        /* Type reference */
    uint16_t offset;                /* Offset in generated per-group structure */
    uint16_t property;              /* Property id in per-object management group */
    bcmolt_prop_access_id access;   /* Access */
} bcmcli_prop_descr;

/* All APIs return
 * BCM_ERR_OK - ok
 * BCM_ERR_NOENT - if id is in range, but doesn't correspond to any value (a hole)
 * BCM_ERR_RANGE - id is out of range
 */

/* Get object name by id */
bcmos_errno api_cli_object_name(bcmolt_obj_id obj, const char **name, const char **descr);

/* Get object structure size */
bcmos_errno api_cli_object_struct_size(bcmolt_obj_id obj, bcmolt_mgt_group group, uint16_t subgroup, uint32_t *key_size, uint32_t *key_offset, uint32_t *data_size, uint32_t *data_offset);

/* Get object subgroup (specific operation or proxy) name and description */
bcmos_errno api_cli_object_subgroup_name(bcmolt_obj_id obj, bcmolt_mgt_group group, uint16_t subgroup, const char **name, const char **descr);

/* Get property by object, mgt_group, subgroup (specific operation or proxy), property_id */
bcmos_errno api_cli_object_property(bcmolt_obj_id obj, bcmolt_mgt_group group, uint16_t subgroup, uint16_t prop, const bcmcli_prop_descr **descr);

/* Get the number of subgroups present for a given group */
static inline uint16_t api_cli_get_subgroup_count(bcmolt_obj_id obj, bcmolt_mgt_group group)
{
    uint16_t count = 0;
    uint32_t dummy;
    while (api_cli_object_struct_size(obj, group, count, &dummy, &dummy, &dummy, &dummy) != BCM_ERR_RANGE)
    {
        ++count;
    }

    return count;
}

/* Dump a single property */
bcmos_errno apicli_dump_prop(bcmcli_session *session, const bcmcli_prop_descr *pd, void *prop_data);

/* Dump a single property value in C initializer format */
bcmos_errno apicli_dump_prop_initializer(bcmcli_session *session, const bcmcli_prop_descr *pd, void *prop_data);

/* Dump a dynamic array in C initializer format */
bcmos_errno apicli_dump_dyn_array(bcmcli_session *session, const bcmcli_type_descr *td, void *data, const char *name);

/* Dump property as CLI parameters */
bcmos_errno apicli_dump_prop_param(bcmcli_session *session, const bcmcli_prop_descr *pd, void *prop_data, const char *prefix);

/* Dump message */
bcmos_errno apicli_msg_dump(bcmcli_session *session, bcmolt_msg *msg);

/* Message group name */
const char *apicli_mgt_group_to_str(bcmolt_mgt_group group);

/* Convert an enum value to the corresponding string */
#define BCMOLT_ENUM_STRING_VAL(enum_name, value)    bcmcli_enum_stringval(enum_name ## _string_table, (value))

/* Enum string tables */
extern bcmcli_enum_val bcmolt_activation_fail_reason_string_table[];
extern bcmcli_enum_val bcmolt_additional_bw_eligibility_string_table[];
extern bcmcli_enum_val bcmolt_ae_ni_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_ni_en_state_string_table[];
extern bcmcli_enum_val bcmolt_ae_ni_key_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_ni_set_ae_ni_en_state_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_ds_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_ds_key_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_ds_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_ds_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_ds_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_ds_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_us_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_us_key_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_us_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_us_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_us_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_ae_path_us_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_alloc_operation_string_table[];
extern bcmcli_enum_val bcmolt_alloc_state_string_table[];
extern bcmcli_enum_val bcmolt_alloc_type_string_table[];
extern bcmcli_enum_val bcmolt_alloc_type_to_scan_string_table[];
extern bcmcli_enum_val bcmolt_api_capture_buffer_mode_string_table[];
extern bcmcli_enum_val bcmolt_api_capture_location_string_table[];
extern bcmcli_enum_val bcmolt_calibration_record_string_table[];
extern bcmcli_enum_val bcmolt_sign_string_table[];
extern bcmcli_enum_val bcmolt_upstream_line_rate_capabilities_string_table[];
extern bcmcli_enum_val bcmolt_link_type_string_table[];
extern bcmcli_enum_val bcmolt_capture_strobe_signal_string_table[];
extern bcmcli_enum_val bcmolt_channel_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_channel_key_id_string_table[];
extern bcmcli_enum_val bcmolt_console_redirection_string_table[];
extern bcmcli_enum_val bcmolt_control_state_string_table[];
extern bcmcli_enum_val bcmolt_dba_mode_string_table[];
extern bcmcli_enum_val bcmolt_dba_ram_string_table[];
extern bcmcli_enum_val bcmolt_dba_type_string_table[];
extern bcmcli_enum_val bcmolt_ddr_test_status_string_table[];
extern bcmcli_enum_val bcmolt_ddr_test_result_string_table[];
extern bcmcli_enum_val bcmolt_host_connection_fail_reason_string_table[];
extern bcmcli_enum_val bcmolt_deactivation_reason_string_table[];
extern bcmcli_enum_val bcmolt_debug_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_debug_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_debug_cli_input_id_string_table[];
extern bcmcli_enum_val bcmolt_debug_cli_output_id_string_table[];
extern bcmcli_enum_val bcmolt_debug_file_almost_full_id_string_table[];
extern bcmcli_enum_val bcmolt_debug_key_id_string_table[];
extern bcmcli_enum_val bcmolt_debug_reset_api_capture_id_string_table[];
extern bcmcli_enum_val bcmolt_debug_start_api_capture_id_string_table[];
extern bcmcli_enum_val bcmolt_debug_stop_api_capture_id_string_table[];
extern bcmcli_enum_val bcmolt_device_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_device_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_device_chip_revision_string_table[];
extern bcmcli_enum_val bcmolt_device_connect_id_string_table[];
extern bcmcli_enum_val bcmolt_device_connection_complete_id_string_table[];
extern bcmcli_enum_val bcmolt_device_connection_established_id_string_table[];
extern bcmcli_enum_val bcmolt_device_connection_failure_id_string_table[];
extern bcmcli_enum_val bcmolt_device_ddr_test_complete_id_string_table[];
extern bcmcli_enum_val bcmolt_device_device_keep_alive_id_string_table[];
extern bcmcli_enum_val bcmolt_device_device_ready_id_string_table[];
extern bcmcli_enum_val bcmolt_device_disconnect_id_string_table[];
extern bcmcli_enum_val bcmolt_device_disconnection_complete_id_string_table[];
extern bcmcli_enum_val bcmolt_device_host_keep_alive_id_string_table[];
extern bcmcli_enum_val bcmolt_device_image_transfer_complete_id_string_table[];
extern bcmcli_enum_val bcmolt_device_image_transfer_data_id_string_table[];
extern bcmcli_enum_val bcmolt_device_image_transfer_start_id_string_table[];
extern bcmcli_enum_val bcmolt_device_image_type_string_table[];
extern bcmcli_enum_val bcmolt_device_indications_dropped_id_string_table[];
extern bcmcli_enum_val bcmolt_device_key_id_string_table[];
extern bcmcli_enum_val bcmolt_nni_speed_string_table[];
extern bcmcli_enum_val bcmolt_device_reset_id_string_table[];
extern bcmcli_enum_val bcmolt_device_reset_mode_string_table[];
extern bcmcli_enum_val bcmolt_device_run_ddr_test_id_string_table[];
extern bcmcli_enum_val bcmolt_device_state_string_table[];
extern bcmcli_enum_val bcmolt_device_sw_error_id_string_table[];
extern bcmcli_enum_val bcmolt_device_sw_exception_id_string_table[];
extern bcmcli_enum_val bcmolt_device_sw_upgrade_activate_id_string_table[];
extern bcmcli_enum_val bcmolt_disable_serial_number_control_string_table[];
extern bcmcli_enum_val bcmolt_drv_icf_id_string_table[];
extern bcmcli_enum_val bcmolt_drv_sgb_id_string_table[];
extern bcmcli_enum_val bcmolt_ds_vlan_action_string_table[];
extern bcmcli_enum_val bcmolt_tfb_trap_behavior_string_table[];
extern bcmcli_enum_val bcmolt_tfb_mode_string_table[];
extern bcmcli_enum_val bcmolt_lim_sec_mode_up_string_table[];
extern bcmcli_enum_val bcmolt_lim_sec_mode_dn_string_table[];
extern bcmcli_enum_val bcmolt_xim_sec_mode_string_table[];
extern bcmcli_enum_val bcmolt_hsc_ram_string_table[];
extern bcmcli_enum_val bcmolt_lim_ram_string_table[];
extern bcmcli_enum_val bcmolt_lky_ram_string_table[];
extern bcmcli_enum_val bcmolt_mic_ram_string_table[];
extern bcmcli_enum_val bcmolt_xpcsrm_ram_string_table[];
extern bcmcli_enum_val bcmolt_embedded_image_transfer_status_string_table[];
extern bcmcli_enum_val bcmolt_epon_encryption_information_format_string_table[];
extern bcmcli_enum_val bcmolt_energy_detect_source_string_table[];
extern bcmcli_enum_val bcmolt_epon_1g_turbo_mode_string_table[];
extern bcmcli_enum_val bcmolt_epon_clock_transport_mode_string_table[];
extern bcmcli_enum_val bcmolt_epon_dba_reporting_mode_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_rate_string_table[];
extern bcmcli_enum_val bcmolt_status_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_key_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_laser_on_off_violation_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_llid_pool_empty_violation_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_max_link_violation_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_overhead_profile_violation_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_range_violation_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_rogue_violation_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_system_resource_violation_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_tdm_channels_exhausted_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_unknown_link_violation_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_denied_link_upstream_bandwidth_violation_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_encryption_mode_string_table[];
extern bcmcli_enum_val bcmolt_epon_key_choice_string_table[];
extern bcmcli_enum_val bcmolt_epon_encryption_direction_string_table[];
extern bcmcli_enum_val bcmolt_epon_fec_en_state_string_table[];
extern bcmcli_enum_val bcmolt_epon_oam_type_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_delete_link_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_duplicate_mpcp_registration_request_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_encryption_enabled_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_fec_state_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_force_rediscovery_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_frame_captured_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_status_string_table[];
extern bcmcli_enum_val bcmolt_mpcp_discovery_info_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_inject_frame_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_key_exchange_failure_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_key_exchange_start_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_key_exchange_started_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_key_exchange_stop_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_key_exchange_stopped_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_key_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_link_deleted_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_link_speed_mismatch_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_mpcp_deregistered_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_mpcp_discovered_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_mpcp_reg_ack_timeout_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_mpcp_report_timeout_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_oam_keepalive_timeout_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_oam_keepalive_timer_start_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_oam_keepalive_timer_started_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_oam_keepalive_timer_stop_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_oam_keepalive_timer_stopped_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_preprovisioned_link_created_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_protection_switch_occurred_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_range_value_changed_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_rerange_failure_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_state_flags_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_static_registration_done_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_static_registration_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_link_type_string_table[];
extern bcmcli_enum_val bcmolt_mpcp_gate_mode_string_table[];
extern bcmcli_enum_val bcmolt_mpcp_registration_gate_flags_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_add_link_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_add_multicast_link_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_add_protected_standby_link_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_auto_rogue_scan_10g_failure_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_auto_rogue_scan_1g_failure_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_en_state_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_issue_rssi_grant_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_key_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_llid_quarantined_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_mpcp_timestamp_changed_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_no_reports_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_onu_upgrade_complete_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_protection_switching_apply_rerange_delta_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_rerange_failure_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_rogue_llid_scan_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_rogue_scan_complete_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_rssi_measurement_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_set_epon_ni_en_state_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_start_onu_upgrade_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_ni_state_change_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_oam_extension_type_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_10g_us_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_10g_us_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_10g_us_key_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_10g_us_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_10g_us_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_10g_us_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_10g_us_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_1g_us_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_1g_us_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_1g_us_key_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_1g_us_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_1g_us_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_1g_us_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_1g_us_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_upgrade_onu_response_code_string_table[];
extern bcmcli_enum_val bcmolt_epon_onu_upgrade_return_code_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_ds_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_ds_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_ds_key_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_ds_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_ds_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_ds_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_ds_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_us_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_us_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_us_key_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_us_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_us_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_us_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_10g_us_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_ds_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_ds_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_ds_key_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_ds_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_ds_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_ds_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_ds_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_us_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_us_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_us_key_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_us_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_us_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_us_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_path_1g_us_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_protection_state_string_table[];
extern bcmcli_enum_val bcmolt_epon_protection_switching_type_string_table[];
extern bcmcli_enum_val bcmolt_protection_switching_detection_options_string_table[];
extern bcmcli_enum_val bcmolt_epon_protection_switching_reranging_options_string_table[];
extern bcmcli_enum_val bcmolt_gpio_pin_string_table[];
extern bcmcli_enum_val bcmolt_gpio_polarity_string_table[];
extern bcmcli_enum_val bcmolt_epon_rp_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_epon_rp_key_id_string_table[];
extern bcmcli_enum_val bcmolt_ext_irq_string_table[];
extern bcmcli_enum_val bcmolt_flush_mac_table_option_string_table[];
extern bcmcli_enum_val bcmolt_frequency_adjustment_direction_string_table[];
extern bcmcli_enum_val bcmolt_gem_port_direction_string_table[];
extern bcmcli_enum_val bcmolt_gem_port_type_string_table[];
extern bcmcli_enum_val bcmolt_gem_port_operation_string_table[];
extern bcmcli_enum_val bcmolt_gpio_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpio_key_id_string_table[];
extern bcmcli_enum_val bcmolt_gpio_pin_dir_string_table[];
extern bcmcli_enum_val bcmolt_gpio_value_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_configuration_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_get_alloc_stats_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_get_stats_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_key_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_set_state_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_alloc_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_gem_port_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_gem_port_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_gem_port_configuration_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_gem_port_key_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_gem_port_set_state_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_gem_port_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_gem_port_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_gem_port_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_gem_port_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_gem_port_state_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_ds_egress_flow_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_ds_egress_flow_key_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_ds_ingress_flow_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_ds_ingress_flow_key_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_flush_mac_table_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_flush_mac_table_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_key_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_mac_table_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_mac_table_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_mac_table_key_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_mac_table_mac_aged_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_mac_table_mac_dropped_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_mac_table_mac_move_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_mac_table_new_mac_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_scan_mac_table_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_scan_mac_table_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_us_flow_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_iwf_us_flow_key_id_string_table[];
extern bcmcli_enum_val bcmolt_key_exchange_mode_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_activate_all_onus_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_broadcast_ploam_packet_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_cpu_packets_failure_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_cpu_packets_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_deactivate_all_onus_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_disable_all_onus_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_disable_serial_number_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_enable_all_onus_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_key_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_los_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_onu_discovered_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_onu_upgrade_complete_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_protection_switching_onus_ranged_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_protection_switching_switchover_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_protection_switching_traffic_resume_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_protection_switching_type_c_set_multiple_onu_state_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_reset_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_rogue_detection_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_rogue_detection_window_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_rogue_onu_special_map_cycle_start_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_serial_number_acquisition_cycle_start_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_set_onu_state_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_set_pon_state_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_single_request_standby_pon_monitoring_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_standby_pon_monitoring_cycle_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_start_onu_upgrade_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_state_change_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_tod_request_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_ni_tod_request_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_ber_interval_configuration_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_change_power_level_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_cpu_packet_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_cpu_packets_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_dfi_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_dgi_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_dowi_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_err_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_invalid_dbru_report_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_key_exchange_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_key_exchange_cycle_skipped_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_key_exchange_decrypt_required_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_key_exchange_key_mismatch_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_key_exchange_key_request_timeout_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_key_exchange_unconsecutive_index_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_key_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_loai_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_loki_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_memi_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_omci_packet_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_omci_port_id_configuration_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_onu_activation_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_onu_activation_standby_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_onu_alarm_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_onu_deactivation_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_onu_disable_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_onu_enable_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_optical_reflection_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_password_authentication_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_pee_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_ploam_packet_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_possible_drift_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_power_management_state_change_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_pst_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_ranging_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_rei_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_rssi_measurement_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_rssi_measurement_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_sdi_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_set_onu_state_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_sfi_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_sufi_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_tiwi_id_string_table[];
extern bcmcli_enum_val bcmolt_omci_device_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_onu_upgrade_return_code_string_table[];
extern bcmcli_enum_val bcmolt_omci_result_code_string_table[];
extern bcmcli_enum_val bcmolt_onu_state_string_table[];
extern bcmcli_enum_val bcmolt_rssi_location_sign_string_table[];
extern bcmcli_enum_val bcmolt_onu_post_discovery_mode_string_table[];
extern bcmcli_enum_val bcmolt_gpon_trx_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_gpon_trx_key_id_string_table[];
extern bcmcli_enum_val bcmolt_image_transfer_status_string_table[];
extern bcmcli_enum_val bcmolt_iwf_mode_string_table[];
extern bcmcli_enum_val bcmolt_log_entry_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_log_entry_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_log_entry_key_id_string_table[];
extern bcmcli_enum_val bcmolt_log_entry_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_log_entry_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_log_entry_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_log_entry_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_log_file_id_string_table[];
extern bcmcli_enum_val bcmolt_log_level_string_table[];
extern bcmcli_enum_val bcmolt_log_style_string_table[];
extern bcmcli_enum_val bcmolt_log_type_string_table[];
extern bcmcli_enum_val bcmolt_logger_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_logger_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_logger_clear_log_id_string_table[];
extern bcmcli_enum_val bcmolt_logger_key_id_string_table[];
extern bcmcli_enum_val bcmolt_logger_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_logger_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_logger_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_logger_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_mac_table_miss_fallback_string_table[];
extern bcmcli_enum_val bcmolt_mac_table_learning_mode_string_table[];
extern bcmcli_enum_val bcmolt_mapping_tag_method_string_table[];
extern bcmcli_enum_val bcmolt_nni_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_nni_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_nni_connection_string_table[];
extern bcmcli_enum_val bcmolt_nni_key_id_string_table[];
extern bcmcli_enum_val bcmolt_trivalent_string_table[];
extern bcmcli_enum_val bcmolt_nni_serdes_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_nni_serdes_key_id_string_table[];
extern bcmcli_enum_val bcmolt_nni_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_nni_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_nni_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_nni_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_nni_status_changed_id_string_table[];
extern bcmcli_enum_val bcmolt_odn_class_string_table[];
extern bcmcli_enum_val bcmolt_omci_port_id_operation_string_table[];
extern bcmcli_enum_val bcmolt_onu_operation_string_table[];
extern bcmcli_enum_val bcmolt_onu_power_level_string_table[];
extern bcmcli_enum_val bcmolt_tc_protocol_string_table[];
extern bcmcli_enum_val bcmolt_packet_injection_error_string_table[];
extern bcmcli_enum_val bcmolt_packet_type_string_table[];
extern bcmcli_enum_val bcmolt_password_authentication_fail_reason_string_table[];
extern bcmcli_enum_val bcmolt_polarity_string_table[];
extern bcmcli_enum_val bcmolt_polling_interval_string_table[];
extern bcmcli_enum_val bcmolt_pon_operation_string_table[];
extern bcmcli_enum_val bcmolt_pon_protection_switching_options_string_table[];
extern bcmcli_enum_val bcmolt_pon_state_string_table[];
extern bcmcli_enum_val bcmolt_power_levelling_control_string_table[];
extern bcmcli_enum_val bcmolt_power_management_transition_reason_string_table[];
extern bcmcli_enum_val bcmolt_prbs_polynomial_string_table[];
extern bcmcli_enum_val bcmolt_prbs_checker_mode_string_table[];
extern bcmcli_enum_val bcmolt_prbs_lock_state_string_table[];
extern bcmcli_enum_val bcmolt_raman_mitigation_mode_string_table[];
extern bcmcli_enum_val bcmolt_ranging_fail_reason_string_table[];
extern bcmcli_enum_val bcmolt_registration_behavior_string_table[];
extern bcmcli_enum_val bcmolt_request_registration_fail_reason_string_table[];
extern bcmcli_enum_val bcmolt_result_string_table[];
extern bcmcli_enum_val bcmolt_rogue_detection_algorithm_type_string_table[];
extern bcmcli_enum_val bcmolt_rogue_detection_window_string_table[];
extern bcmcli_enum_val bcmolt_rogue_measurement_result_string_table[];
extern bcmcli_enum_val bcmolt_rogue_scan_status_string_table[];
extern bcmcli_enum_val bcmolt_rssi_measurement_fail_reason_string_table[];
extern bcmcli_enum_val bcmolt_secure_mutual_authentication_fail_reason_string_table[];
extern bcmcli_enum_val bcmolt_serdes_ranging_mode_string_table[];
extern bcmcli_enum_val bcmolt_serdes_instance_string_table[];
extern bcmcli_enum_val bcmolt_shaper_mode_string_table[];
extern bcmcli_enum_val bcmolt_software_error_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_software_error_key_id_string_table[];
extern bcmcli_enum_val bcmolt_stat_condition_type_string_table[];
extern bcmcli_enum_val bcmolt_switch_over_type_c_onu_state_string_table[];
extern bcmcli_enum_val bcmolt_system_mode_string_table[];
extern bcmcli_enum_val bcmolt_us_operating_wavelength_bands_string_table[];
extern bcmcli_enum_val bcmolt_traffic_resume_result_string_table[];
extern bcmcli_enum_val bcmolt_trx_calibration_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_trx_calibration_capture_window_and_statistic_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_trx_calibration_key_id_string_table[];
extern bcmcli_enum_val bcmolt_trx_calibration_start_capture_window_id_string_table[];
extern bcmcli_enum_val bcmolt_trx_calibration_stop_capture_window_id_string_table[];
extern bcmcli_enum_val bcmolt_trx_calibration_trigger_string_table[];
extern bcmcli_enum_val bcmolt_trx_calibration_trigger_position_string_table[];
extern bcmcli_enum_val bcmolt_trx_calibration_window_mode_string_table[];
extern bcmcli_enum_val bcmolt_trx_type_string_table[];
extern bcmcli_enum_val bcmolt_tune_in_fail_reason_string_table[];
extern bcmcli_enum_val bcmolt_tune_out_fail_reason_string_table[];
extern bcmcli_enum_val bcmolt_uart_baudrate_string_table[];
extern bcmcli_enum_val bcmolt_us_gem_port_destination_string_table[];
extern bcmcli_enum_val bcmolt_us_vlan_action_string_table[];
extern bcmcli_enum_val bcmolt_vlan_to_flow_mapping_method_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_configuration_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_get_alloc_stats_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_get_stats_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_key_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_set_state_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_alloc_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_gem_port_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_gem_port_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_gem_port_key_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_gem_port_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_gem_port_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_gem_port_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_gem_port_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_gem_port_state_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_iwf_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_iwf_key_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_activate_all_onus_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_adjust_tx_wavelength_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_broadcast_ploam_packet_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_cpu_packets_failure_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_cpu_packets_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_deactivate_all_onus_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_disable_all_onus_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_disable_serial_number_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_enable_all_onus_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_key_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_los_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_onu_discovered_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_onu_upgrade_complete_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_protection_switching_onus_ranged_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_protection_switching_switchover_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_protection_switching_traffic_resume_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_reset_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_rogue_detection_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_rogue_detection_window_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_rogue_onu_special_map_cycle_start_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_run_special_bw_map_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_serial_number_acquisition_cycle_start_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_set_onu_state_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_set_pon_state_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_single_request_standby_pon_monitoring_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_standby_pon_monitoring_cycle_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_start_onu_upgrade_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_state_change_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_tod_request_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_ni_tod_request_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_num_of_onus_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_adjust_tx_wavelength_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_auto_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_change_power_levelling_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_cpu_packet_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_cpu_packets_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_dfi_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_dgi_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_dowi_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_get_power_consumption_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_get_power_level_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_invalid_dbru_report_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_key_exchange_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_key_exchange_cycle_skipped_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_key_exchange_key_mismatch_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_key_exchange_key_request_timeout_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_key_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_looci_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_omci_packet_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_onu_activation_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_onu_alarm_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_onu_deactivation_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_onu_disable_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_onu_enable_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_onu_tuning_in_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_onu_tuning_in_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_onu_tuning_out_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_onu_tuning_out_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_optical_reflection_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_ploam_packet_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_possible_drift_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_power_consumption_report_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_power_level_report_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_power_management_state_change_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_pqsi_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_ranging_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_registration_id_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_request_registration_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_rssi_measurement_completed_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_rssi_measurement_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_sdi_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_secure_mutual_authentication_failure_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_secure_mutual_authentication_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_set_onu_state_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_sfi_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_stat_alarm_cleared_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_stat_alarm_raised_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_stat_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_stat_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_sufi_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_tiwi_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_onu_tuning_response_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_serdes_ranging_mode_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_trx_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_trx_key_id_string_table[];
extern bcmcli_enum_val bcmolt_xgpon_trx_type_string_table[];
extern bcmcli_enum_val bcmolt_xpon_serdes_cfg_id_string_table[];
extern bcmcli_enum_val bcmolt_xpon_serdes_key_id_string_table[];

#ifdef __cplusplus
}
#endif
#endif /* MAPLE_CLI_HELPERS_H_ */
